@@ -2,7 +2,7 @@ package App::RecordStream::Bio;
 
 use strict;
 use 5.010;
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 # For informational purposes only in the fatpacked file, so it's OK to fail.
 # For now, classes are still under the App::RecordStream::Operation namespace
@@ -57,6 +57,9 @@ L<recs-fromsam>
 
 L<recs-tofasta>
 
+Looking for C<fromfastq> or C<tofastq>?  Install the
+L<recs-fastq|https://github.com/MullinsLab/recs-fastq> package.
+
 =head1 INSTALLATION
 
 =head2 Quick, standalone bundle
